==> haskell-crypton-x509-system-1.6.7-96-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-x509-system
version:              1.6.7
visibility:           public
id:                   crypton-x509-system-1.6.7-Izlshxdct4H5sMVPXp7yc6
key:                  crypton-x509-system-1.6.7-Izlshxdct4H5sMVPXp7yc6
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             Handle per-operating-system X.509 accessors and storage
description:
    System X.509 handling for accessing operating system dependents store and other storage methods

category:             Data
abi:                  b6192dea56c2384ca1ec4a3c08c1c579
exposed:              True
exposed-modules:      System.X509 System.X509.MacOS System.X509.Unix
import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypton-x509-system-1.6.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypton-x509-system-1.6.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypton-x509-system-1.6.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509-system
hs-libraries:         HScrypton-x509-system-1.6.7-Izlshxdct4H5sMVPXp7yc6
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    crypton-x509-1.7.7-GkjVeOU6yChDIHLArvUhzC
    crypton-x509-store-1.6.11-3tdfJIhlLJsJz6KMCipqYb directory-1.3.7.1
    filepath-1.4.2.2 mtl-2.2.2 pem-0.2.4-9JnffZmm6wnGbAdbIdxAQs
    process-1.6.18.0

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509-system/html/crypton-x509-system.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509-system/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypton-x509-system-1.6.7-97-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-x509-system
version:              1.6.7
visibility:           public
id:                   crypton-x509-system-1.6.7-G0JKsytHpeXHJu9dKbgfYu
key:                  crypton-x509-system-1.6.7-G0JKsytHpeXHJu9dKbgfYu
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             Handle per-operating-system X.509 accessors and storage
description:
    System X.509 handling for accessing operating system dependents store and other storage methods

category:             Data
abi:                  c14627920e87e4cf55ea0ef8638dfea2
exposed:              True
exposed-modules:      System.X509 System.X509.MacOS System.X509.Unix
import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypton-x509-system-1.6.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypton-x509-system-1.6.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypton-x509-system-1.6.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509-system
hs-libraries:         HScrypton-x509-system-1.6.7-G0JKsytHpeXHJu9dKbgfYu
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    crypton-x509-1.7.7-AU3bHGaLMZjEYRZ1nEAQau
    crypton-x509-store-1.6.11-BM2apfbzPiB9Cox1BZbuH7 directory-1.3.7.1
    filepath-1.4.2.2 mtl-2.2.2 pem-0.2.4-IlUHgcf1qJ9IJWb4yoyQPD
    process-1.6.18.0

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509-system/html/crypton-x509-system.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509-system/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
